Welcome to PolSARtools’ Documentation! — PolSARtools 0.8 documentation

Skip to main content
`Ctrl`+`K`

# Welcome to PolSARtools’ Documentation!

PolSARtools is a Python package available on PyPI 🐍 that generates derived SAR parameters, including:

- 🌀 Polarimetric descriptors

- 🌿 Vegetation indices

- 🧩 Polarimetric decomposition parameters

It supports input from various SAR sensors or directly from polarimetric matrices such as: `S2`, `C3`, `T3`, `C2`, `T2`.

## 📘 Tutorial Notebooks

Get started quickly with hands-on examples! Explore our step-by-step tutorials here: 👉 polsartools-notebooks 📓✨

## 📚 Cite Us!

If you use PolSARtools in your research or projects, we’d really appreciate a citation! 🛰️✨

Please cite our work as:

> Bhogapurapu, N., Dey, S., Mandal, D., Bhattacharya, A., and Rao, Y.S. (2021). PolSAR tools: A QGIS plugin for generating SAR descriptors. Journal of Open Source Software, 6(60), p.2970. 🔗 https://doi.org/10.21105/joss.02970

### BibTeX 📄

    @article{bhogapurapu2021polsar,
      title={PolSAR tools: A QGIS plugin for generating SAR descriptors},
      author={Bhogapurapu, Narayanarao and Dey, Subhadip and Mandal, Dipankar and Bhattacharya, Avik and Rao, YS},
      journal={Journal of Open Source Software},
      volume={6},
      number={60},
      pages={2970},
      year={2021},
      doi={10.21105/joss.02970}
    }

🙏 Your support means a lot and helps us keep improving PolSARtools!

Contents:

- Getting started
  - 💾 Installation
  - Example Usage
  - 🤝 Contributing
    - How to Contribute
  - 🐞 Bug Reporting
  - 💡 Feature Requests
  - 📚 Cite Us!
    - BibTeX 📄
- Supported sensors
  - 🔸UAVSAR
    - GRD (`uavsar_grd`)
    - MLC (`uavsar_mlc`)
  - 🔸ISRO ASAR
    - RSLC (`isro_asar`)
  - 🔸ESAR
    - GTC SLC (`esar_gtc`)
  - 🔸NISAR
    - RSLC (`nisar_rslc`)
    - GSLC (`nisar_gslc`)
  - 🔸RISAT-1A
    - Level 1.1 (`risat_l11`)
  - 🔸RADARSAT-2
    - Full-pol (`rs2_fp`)
  - 🔸ALOS-2 PALSAR-2
    - FBD L1.1 (`alos2_fbd_l11`)
    - HBQ L1.1 (`alos2_hbq_l11`)
  - 🔸Chandrayaan-II (DFSAR)
    - Full-pol (`chyaan2_fp`)
- Functions
  - Full-pol functions
    - Full-pol data format
    - H/A/α Decomposition (`halphafp`)
    - Yamaguchi 4-Component decomposition (`yam4cfp`)
    - Model Free 3-Component decomposition (`mf3cf`)
    - Model Free 4-Component decomposition (`mf4cf`)
    - Neumann decomposition (`neufp`)
    - Non-negative Eigen Value decomposition (`nnedfp`)
    - Shannon entropy (`shannon_h_fp`)
    - Radar Vegetation Index (`rvifp` )
    - Generalized volume based Radar Vegetation Index (`grvi`)
    - Polarimetric Radar Vegetation Index (`prvifp` )
    - Degree of Polarization (`dopfp`)
  - Compact-pol functions
    - Compact-pol data format
    - Compact-pol Radar Vegetation Index (`cprvi`)
    - improved S-\(\Omega\) decomposition (`misomega`)
    - Model Free 3-Component decomposition (`mf3cc`)
    - Degree of Polarization (`dopcp`)
  - Dual-pol functions
    - Dual-pol data format
    - Radar Vegetation Index (`rvidp`)
    - Dual-pol Radar Vegetation Index (`dprvi`)
    - Polarimetric Radar Vegetation Index (`prvidp`)
    - Degree of Polarization (`dopdp`)
    - H/α decomposition (`halphadp`)
    - Shannon entropy (`shannon_h_dp`)
    - Model Free 3-Component decomposition for dual-co-pol (`mf3cd`)
    - Dual-pol Radar Vegetation Index for GRD (`dprvic`)
    - Dual polarimetric descriptors (`dp_desc`)
  - Polarimetric speckle filters
    - Refined-Lee filter (`rlee`)
    - Boxcar filter (`boxcar`)
  - other functions
    - Multi-looking (`mlook`)
    - Conver full-pol S2 (`convert_S`)
    - Derive stokes parameters (`stokes_parm`)
    - Generate pauliRGB for FP data (`pauliRGB`)
    - Generate false color RGB for DP/CP data (`dxpRGB`)
    - Generate false color RGB for decomposed powers (`rgb`)
    - Generate polarimetric signatures for FP data (`fp_sign`)
    - Full-pol H-alpha plot (`halpha_plot_fp`)
    - Dual-pol H-alpha plot (`halpha_plot_dp`)
- References

## Disclaimer

PolSARtools v0.6.1 is released under the GNU General Public License v3.0 (GPL-3.0). This means you are free to use, modify, and distribute the software, provided you adhere to the terms of the license.

### No Warranty

This software is provided “as is”, without warranty of any kind, either express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose, and non-infringement. In no event shall the authors or copyright holders be liable for any claim, damages, or other liability, whether in an action of contract, tort, or otherwise, arising from, out of, or in connection with the software or the use or other dealings in the software.

Use this software at your own risk. While efforts have been made to ensure reliability and accuracy, no guarantee is provided regarding its suitability for any particular application.